@@ -7,7 +7,7 @@ use 5.006001;
 use strict;
 use Config;
 
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 
 use CPANPLUS::Internals::Source;
@@ -38,7 +38,7 @@ use vars qw[@ISA $VERSION];
             CPANPLUS::Internals::Report
         ];
 
-$VERSION = "0.059_01";
+$VERSION = "0.070_04";
 
 =pod
 
@@ -474,13 +474,6 @@ Return all stored objects.
     sub _return_all_objects { return values %$idref }
 }
 
-sub END {
-    my @obs = __PACKAGE__->_return_all_objects();
-
-    $obs[0]->_save_source() if scalar @obs;
-}
-
-
 1;
 
 # Local variables:
